Stimuli Delivery — BCI-Framework documentation

# Stimuli Delivery

The stimuli delivery consist in a reimplementation of Brython-Radiant with some renames and a preconfigured server.

class `bci_framework.extensions.stimuli_delivery.stimuli_delivery.` `StimuliAPI`

  Rename Randiant with a arand new class.

`bci_framework.extensions.stimuli_delivery.stimuli_delivery.` `StimuliServer`(class_, *args, **kwargs)

  Rename RadiantServer with a preconfigured StimuliServer.

class `bci_framework.extensions.stimuli_delivery.stimuli_delivery.` `_delivery_instance`

  This class make compatible the functional decorators defined with Brython.